@@ -11,8 +11,7 @@ use crate::utils::idf::get_idf;
 use crate::utils::varint;
 use trigrams::get_tri_grams;
 
-pub static DICTIONARY_TABLE_FILE_NAME: &str = "_dictionary_table";
-pub static DICTIONARY_STRING_FILE_NAME: &str = "_dictionary_string";
+pub static DICTIONARY_STRING_FILE_NAME: &str = "dictionary_string";
 
 pub struct Dictionary {
     pub term_infos: FxHashMap<Rc<String>, TermInfo>,
@@ -21,7 +20,7 @@ pub struct Dictionary {
 
 #[inline(always)]
 pub fn setup_dictionary(
-    table_vec: Vec<u8>,
+    table_vec: &[u8],
     string_vec: Vec<u8>,
     num_docs: u32,
     build_trigram: bool,
@@ -36,7 +35,7 @@ pub fn setup_dictionary(
 
     let table_vec_len = table_vec.len();
     while dict_table_pos < table_vec_len {
-        let doc_freq = varint::decode_var_int(&table_vec, &mut dict_table_pos);
+        let doc_freq = varint::decode_var_int(table_vec, &mut dict_table_pos);
 
         // new postings list delimiter
         if doc_freq == 0 {
@@ -45,7 +44,7 @@ pub fn setup_dictionary(
             continue;
         }
 
-        postings_file_offset += varint::decode_var_int(&table_vec, &mut dict_table_pos);
+        postings_file_offset += varint::decode_var_int(table_vec, &mut dict_table_pos);
 
         let prefix_len = string_vec[dict_string_pos] as usize;
         dict_string_pos += 1;
@@ -123,7 +122,7 @@ mod test {
     #[test]
     fn test_dictionary_setup() {
         let dictionary = super::setup_dictionary(
-            vec![
+            &vec![
                 // Format: doc freq var-int, then pl offset var-int
                 129, 127, 127, 131,
                 129, 127, 127, 131,
